@@ -23,9 +23,7 @@ def gradient_map(data: str, model: str,
     :param data: name of the data set
     :param model: path to the TOML file that contains the model information
     :param title: title of the configuration (default: "Config Gradient Map
-    Analysis")
-    :return: a RequestModel instance containing all the information needed to
-    execute a Gradient Map Analysis
+        Analysis")
     """
     request_model = request_factory(
         data=data,
