@@ -21,11 +21,9 @@ def performance(data: str, model: str, report=True,
     :param data: name of the data set
     :param model: path to the TOML file that contains the model information
     :param report: whether to create a performance report or not (default:
-    True)
+        True)
     :param title: title of the configuration (default: "Config Performance
-    Analysis")
-    :return: a RequestModel instance containing all the information needed to
-    execute a Performance Analysis
+        Analysis")
     """
     request_model = request_factory(
         title=title,
