@@ -1,92 +1,21 @@
 """Create a RequestModel to execute a Key Robustness Indicator analysis."""
-from dataclasses import dataclass
-from typing import Dict
-from typing import List, Union
+from typing import Dict, List, Union
 
 from aidkitcli.core.analyses.kri import kri as request_factory
+from aidkitcli.core.analyses.kri import (
+    Distribution,
+    ConstantDistribution,
+    RelativeConstantDistribution,
+    IncreaseDistribution,
+    RandomDistribution,
+    FGSMDistribution,
+    CorrelationDistribution,
+    PeakDistribution,
+    BlackboxDistribution
+)
 from aidkitcli.data_access.analysis import post_analysis
 
 
-@dataclass
-class Distribution:
-    start_index: int
-    perturbation_length: int
-    saver: int
-
-
-@dataclass
-class ConstantDistribution(Distribution):
-    variable_name: str
-    constant: Union[float, str]
-    name: str = "constant"
-
-
-@dataclass
-class RelativeConstantDistribution(Distribution):
-    variable_name: str
-    relative_constant: float
-    name: str = "relative_constant"
-
-
-@dataclass
-class IncDecDistribution(Distribution):
-    variable_name: str
-    factor: float
-    start_constant: float
-    end_constant: float
-    step_length: int
-    name: str = "inc_dec"
-
-
-@dataclass
-class RandomDistribution(Distribution):
-    variable_name: str
-    lower_bound: float
-    upper_bound: float
-    step_length: int
-    name: str = "random"
-
-
-@dataclass
-class FGSMDistribution(Distribution):
-    epsilon: List[float]
-    iteration_step: int
-    ascend: bool
-    mask: List[int]
-    step_length: List[int]
-    name: str = "fgsm"
-
-
-@dataclass
-class CorrelationDistribution(Distribution):
-    epsilon: List[float]
-    iteration_step: int
-    mask: List[int]
-    step_length: List[int]
-    name: str = "correlation"
-
-
-@dataclass
-class PeakDistribution(Distribution):
-    epsilon: List[float]
-    iteration_step: int
-    mask: List[int]
-    step_length: List[int]
-    name: str = "peak"
-
-
-@dataclass
-class BlackboxDistribution(Distribution):
-    epsilon: List[float]
-    population_nr: int
-    selection_nr: int
-    evolutionary_step: int
-    ascend: bool
-    mask: List[int]
-    step_length: List[int]
-    name: str = "blackbox"
-
-
 def constant_distribution_factory(variable_name: str,
                                   constant: Union[float, str],
                                   start_index: int = 0,
@@ -155,23 +84,23 @@ def relative_constant_distribution_factory(variable_name: str,
     return distribution
 
 
-def inc_dec_distribution_factory(variable_name: str,
-                                 step_length: int,
-                                 start_constant: float,
-                                 end_constant: float,
-                                 start_index: int = 0,
-                                 perturbation_length: int = 100000
-                                 ) -> IncDecDistribution:
+def increase_distribution_factory(variable_name: str,
+                                  step_length: int,
+                                  start_constant: float,
+                                  end_constant: float,
+                                  start_index: int = 0,
+                                  perturbation_length: int = 100000
+                                  ) -> IncreaseDistribution:
     """
     Create a distribution object containing all the parameters needed to
-    execute a Increasing - Decreasing Corruption. This object can then be fed
+    execute a Increase Corruption. This object can then be fed
     to the KRI function to determine a robustness risk score.
 
-    When an Increasing - Decreasing Corruption is executed, the values of the
-    selected variable are first set to the start_constant value and then
-    changed every step_length data points in the file. Depending on whether
-    end_constant is bigger or smaller than start_constant, the values are
-    increased or decreased after step_length data points.
+    When an Increase Corruption is executed, the values of the selected
+    variable are first set to the start_constant value and then changed every
+    step_length data points in the file. Depending on whether end_constant is
+    bigger or smaller than start_constant, the values are increased or
+    decreased after step_length data points.
 
     This corruption can only be applied to quantitative input variables. The
     supported ML models are:
@@ -181,23 +110,17 @@ def inc_dec_distribution_factory(variable_name: str,
 
     :param variable_name: name of the variable to corrupt
     :param step_length: number of data points with a constant value before
-    the next increase/decrease
+        the next increase/decrease
     :param start_constant: starting value of the perturbation
     :param end_constant: maximal corruption value that should not be surpassed
     :param start_index: data points before this index will not be perturbed
     :param perturbation_length: number of data points perturbed
     """
-    if start_constant < end_constant:
-        factor = 1.0
-    else:
-        factor = -1.0
-
-    distribution = IncDecDistribution(
+    distribution = IncreaseDistribution(
         variable_name=variable_name,
         step_length=step_length,
         start_constant=start_constant,
         end_constant=end_constant,
-        factor=factor,
         start_index=start_index,
         perturbation_length=perturbation_length,
         saver=1
@@ -229,7 +152,7 @@ def random_distribution_factory(variable_name: str,
 
     :param variable_name: name of the variable to corrupt
     :param step_length: number of data points with a constant value before
-    the next increase/decrease
+        the next increase/decrease
     :param lower_bound: minimal corruption value which should not be surpassed
     :param upper_bound: maximal corruption value which should not be surpassed
     :param start_index: data points before this index will not be perturbed
@@ -292,11 +215,12 @@ def fgsm_distribution_factory(epsilon: List[float],
     :param perturbation_length: number of data points perturbed
     :param iteration_step: number of iterations in the attack
     :param ascend: whether the output value should increase (True) or decrease
-    (False). Only needed if the attack is applied to a regression model
+        (False). Only needed if the attack is applied to a regression model
     :param mask: list of binary values that decide whether a variable can be
-    perturbed by the attack, the list length must be the number of variables
+        perturbed by the attack, the list length must be the number of
+        variables
     :param step_length: number of time steps with constant value before next
-    increase or decrease
+        increase or decrease
     """
     distribution = FGSMDistribution(
         epsilon=epsilon,
@@ -345,9 +269,10 @@ def correlation_distribution_factory(epsilon: List[float],
     :param perturbation_length: number of data points perturbed
     :param iteration_step: number of iterations in the attack
     :param mask: list of binary values that decide whether a variable can be
-    perturbed by the attack, the list length must be the number of variables
+        perturbed by the attack, the list length must be the number of
+        variables
     :param step_length: number of time steps with constant value before next
-    increase or decrease
+        increase or decrease
     """
     distribution = CorrelationDistribution(
         epsilon=epsilon,
@@ -395,9 +320,10 @@ def peak_distribution_factory(epsilon: List[float],
     :param perturbation_length: number of data points perturbed
     :param iteration_step: number of iterations in the attack
     :param mask: list of binary values that decide whether a variable can be
-    perturbed by the attack, the list length must be the number of variables
+        perturbed by the attack, the list length must be the number of
+        variables
     :param step_length: number of time steps with constant value before next
-    increase or decrease
+        increase or decrease
     """
     distribution = PeakDistribution(
         epsilon=epsilon,
@@ -454,11 +380,12 @@ def blackbox_distribution_factory(epsilon: List[float],
     :param selection_nr: number of perturbations selected from population
     :param evolutionary_step: number of evolutions (crossover/mutations)
     :param ascend: whether the output value should increase (True) or decrease
-    (False)
+        (False)
     :param mask: list of binary values that decide whether a variable can be
-    perturbed by the attack, the list length must be the number of variables
+        perturbed by the attack, the list length must be the number of
+        variables
     :param step_length: number of time steps with constant value before next
-    increase or decrease
+        increase or decrease
     """
     distribution = BlackboxDistribution(
         epsilon=epsilon,
@@ -485,27 +412,29 @@ def kri(data: str, model: str,
     a given data set and realistic distributions for the deployment context.
     The relevance (probability of occurrence) of the data files and the
     distributions is given by the probability vectors p_x and p_cond. The method
-    returns three different risk scores, based on different severity estimation
-    metrics (error metrics):
-        - Average Absolute Error of the predictions w.r.t. the labels (useful
-        for regression)
-        - Maximal Error of the predictions w.r.t. the labels (useful for
-        regression)
-        - Percentage of Errors / Accuracy (useful for classification)
+    returns three different risk scores, based on different severity estimation:
+
+    - Average Absolute Error of the predictions w.r.t. the labels (useful for
+      regression)
+    - Maximal Error of the predictions w.r.t. the labels (useful for
+      regression)
+    - Percentage of Errors / Accuracy (useful for classification)
 
     A more detailed explanation of this analysis can be found in the following
     paper: https://arxiv.org/abs/2011.04328
 
     The analysis can be executed using different corruption distributions
     and adversarial attacks:
-        - "constant" - Constant Corruption
-        - "relative_constant" - Relative Constant Corruption
-        - "inc_dec" - Increase/Decrease Corruption
-        - "random" - Random Corruption
-        - "fgsm" - Fast Gradient Sign Method Attack
-        - "correlation" - Correlation Attack
-        - "peak" - Peak Attack
-        - "blackbox" - Black-Box Attack
+
+    - "constant" - Constant Corruption
+    - "relative_constant" - Relative Constant Corruption
+    - "increase" - Increase Corruption
+    - "random" - Random Corruption
+    - "fgsm" - Fast Gradient Sign Method Attack
+    - "correlation" - Correlation Attack
+    - "peak" - Peak Attack
+    - "blackbox" - Black-Box Attack
+
     Each distribution has its own parameters. Check the documentation of each
     factory method (<distribution_name>_distribution_factory) for a more
     detailed explanation of the different corruptions and attacks and their
@@ -514,17 +443,17 @@ def kri(data: str, model: str,
     :param data: name of the data set
     :param model: path to the TOML file that contains the model information
     :param p_x: list of the probabilities of occurrence of a data file in the
-    deployment context, the length of the list must be equal to the number of
-    data files in the provided data set and the probabilities must sum up to 1
-    :param p_cond: list of the probabilities of each distribution (corruption/
-    attack) given a data set, the length of the list must be equal to the
-    number of distributions and the probabilities must sum up to 1
+        deployment context, the length of the list must be equal to the number
+        of data files in the provided data set and the probabilities must sum
+        up to 1
+    :param p_cond: list of the probabilities of each distribution
+        (corruption/attack) given a data set, the length of the list must be
+        equal to the number of distributions and the probabilities must sum up
+        to 1
     :param distributions: list of the distributions (corruptions/attacks) for
-    the KRI analysis, each distribution is created by its corresponding
-    factory method <distribution_name>_distribution_factory
+        the KRI analysis, each distribution is created by its corresponding
+        factory method <distribution_name>_distribution_factory
     :param title: title of the configuration (default: "Config KRI Analysis")
-    :return: a RequestModel instance containing all the information needed to
-    execute a Key Robustness Indicator analysis
     """
     request_model = request_factory(
         title=title,
