@@ -21,17 +21,17 @@ def performance(data: str, model: str, report=True,
     :param data: name of the data set
     :param model: path to the TOML file that contains the model information
     :param report: whether to create a performance report or not (default:
-    True)
+        True)
     :param title: title of the configuration (default: "Config Performance
-    Analysis")
+        Analysis")
     :return: a RequestModel instance containing all the information needed to
-    execute a Performance Analysis
+        execute a Performance Analysis
     """
     stored_model = load_stored_model(path=model)
     toml_dict = create_toml(
         title=title,
         data=data,
         stored_model=stored_model,
-        performance={report: report}
+        performance={"report": report}
     )
     return RequestModel(toml_dict)
